about summary refs log tree commit diff
path: root/pkgs/development/libraries/glib/default.nix
diff options
context:
space:
mode:
authorJonathan Ringer <jonringer117@gmail.com>2021-01-18 22:50:56 -0800
committerJonathan Ringer <jonringer@users.noreply.github.com>2021-01-19 01:16:25 -0800
commit9bb3fccb5b55326cb3c2c507464a8a28d44d1730 (patch)
tree9d1c0c16cce5e5dcc08115230f6412865487964b /pkgs/development/libraries/glib/default.nix
parent200bb8c977d81ebdf847d5e6839cd46cd3eb8d4d (diff)
downloadnixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.gz
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.bz2
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.lz
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.xz
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.zst
nixlib-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.zip
treewide: pkgs.pkgconfig -> pkgs.pkg-config, move pkgconfig to alias.nix
continuation of #109595

pkgconfig was aliased in 2018, however, it remained in
all-packages.nix due to its wide usage. This cleans
up the remaining references to pkgs.pkgsconfig and
moves the entry to aliases.nix.

python3Packages.pkgconfig remained unchanged because
it's the canonical name of the upstream package
on pypi.
Diffstat (limited to 'pkgs/development/libraries/glib/default.nix')
-rw-r--r--pkgs/development/libraries/glib/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/development/libraries/glib/default.nix b/pkgs/development/libraries/glib/default.nix
index 57f05d410fbf..da1eb0765365 100644
--- a/pkgs/development/libraries/glib/default.nix
+++ b/pkgs/development/libraries/glib/default.nix
@@ -1,4 +1,4 @@
-{ config, stdenv, fetchurl, gettext, meson, ninja, pkgconfig, perl, python3
+{ config, stdenv, fetchurl, gettext, meson, ninja, pkg-config, perl, python3
 , libiconv, zlib, libffi, pcre, libelf, gnome3, libselinux, bash, gnum4, gtk-doc, docbook_xsl, docbook_xml_dtd_45
 # use util-linuxMinimal to avoid circular dependency (util-linux, systemd, glib)
 , util-linuxMinimal ? null
@@ -29,7 +29,7 @@ assert stdenv.isLinux -> util-linuxMinimal != null;
   * Support org.freedesktop.Application, including D-Bus activation from desktop files
 */
 let
   # Some packages don't get "Cflags" from pkgconfig correctly
   # and then fail to build when directly including like <glib/...>.
   # This is intended to be run in postInstall of any package
   # which has $out/include/ containing just some disjunct directories.
@@ -100,7 +100,7 @@ stdenv.mkDerivation rec {
   ]);
 
   nativeBuildInputs = [
-    meson ninja pkgconfig perl python3 gettext gtk-doc docbook_xsl docbook_xml_dtd_45
+    meson ninja pkg-config perl python3 gettext gtk-doc docbook_xsl docbook_xml_dtd_45
   ];
 
   propagatedBuildInputs = [ zlib libffi gettext libiconv ];
@@ -29,7 +29,7 @@ assert stdenv.isLinux -> util-linuxMinimal != null;
 */
 let
-  # Some packages don't get "Cflags" from pkgconfig correctly
+  # Some packages don't get "Cflags" from pkg-config correctly
   # and then fail to build when directly including like <glib/...>.
   # This is intended to be run in postInstall of any package